@@ -27,13 +27,19 @@ An example of updating a tag rule, and forcing reevaluation:
 
     razor update-tag-rule --name small --force \\
         --rule '["<=", ["fact", "processorcount"], "2"]'
+
+With positional arguments, this can be shortened:
+
+    razor update-tag-rule small '[["<=", ["fact", "processorcount"], "2"]]' \\
+        --force
   EOT
 
   authz '%{name}'
   attr  'name', type: String, required: true, references: Razor::Data::Tag,
-                help: _('The tag for which to change the rule.')
+                position: 0, help: _('The tag for which to change the rule.')
 
-  attr 'rule', required: true, type: Array, help: _('The new rule to apply to the tag.')
+  attr 'rule', required: true, type: Array, position: 1,
+               help: _('The new rule to apply to the tag.')
 
   attr 'force', type: :bool, help: _(<<-HELP)
     By default this command will fail if the tag is in use by an existing
