@@ -1,3 +1,4 @@
+# -*- encoding: utf-8 -*-
 # A facade around Razor::Config for use in installer templates, so that the
 # templates only have access to config settings that are explicitly
 # whitelisted for them in Razor::Config::TEMPLATe_PATHS
@@ -9,7 +10,7 @@ module Razor::Util
       if Razor::Config::TEMPLATE_PATHS.include?(key)
         Razor.config[key]
       else
-        raise ConfigAccessProhibited, "The config setting '#{key}' can not be accessed from templates"
+        raise ConfigAccessProhibited, _("The config setting '%{key}' can not be accessed from templates") % {key: key}
       end
     end
   end
